# ghub
A Unix like CLI for GitHub. [![Build Status](https://travis-ci.org/BBloggsbott/ghub.svg?branch=master)](https://travis-ci.org/BBloggsbott/ghub)

For more instructions on setup and usage, check the wiki [here](https://github.com/BBloggsbott/ghub/wiki).

Interested in contributing? Read the contributing guidelines [here](CONTRIBUTING.md).
